..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

Extension
---------

.. automodule:: invenio_accounts.ext
   :members:

Administration
--------------

.. automodule:: invenio_accounts.admin
   :members:

Datastore
---------

.. automodule:: invenio_accounts.datastore
   :members:

Errors
------

.. automodule:: invenio_accounts.errors
   :members:


Forms
-----

.. automodule:: invenio_accounts.forms
   :members:

Hash
----

.. automodule:: invenio_accounts.hash
   :members:

Models
------

.. automodule:: invenio_accounts.models
   :members:


Utils
-----

.. automodule:: invenio_accounts.utils
   :members:

Testing utils
-------------

.. automodule:: invenio_accounts.testutils
  :members:

Tasks
-----

.. autotask:: invenio_accounts.tasks.send_security_email
.. autotask:: invenio_accounts.tasks.clean_session_table

Views
-----

.. automodule:: invenio_accounts.views.security
   :members:

.. automodule:: invenio_accounts.views.settings
   :members:
